/***************************************************************************
						gui3dview.cpp    -  description
							-------------------
	begin                : mar 22th, 2004
	copyright            : (C) 2004 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net

	$Id: gui3dview.cpp 261 2007-10-20 18:22:47Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/

#include "gui3dview.h"
